package WebGUI::i18n::English::Account_Inbox;
use strict;

our $I18N = {

    'mark as read label' => {
        message     => q{Mark as Read},
        lastUpdated => 1241178876,
    },

    'mark as unread label' => {
        message     => q{Mark as Unread},
        lastUpdated => 1241178876,
    },

    'title' => {
        message     => q{Inbox},
        lastUpdated => 1225724810,
        context     => q{Tab label for Inbox Account pluggin},
    },

    'inbox style template label' => {
        message     => q|Style Template|,
        lastUpdated => 1119068809
	},

    'inbox style template hoverHelp' => {
        message     => q|Select a style template from the list to enclose the inbox in.|,
        lastUpdated => 1119068809
	},

    'inbox layout template label' => {
        message     => q|Edit Layout Template|,
        lastUpdated => 1119068809
	},

    'inbox layout template hoverHelp' => {
        message     => q{Choose a layout from the list to display the various account pluggins that are editable by the current user as well as the contents of the one currently chosen},
        lastUpdated => 1119068809
    },

    'inbox view template label' => {
        message     => q|View Template|,
        lastUpdated => 1119068809
    },

    'inbox view template hoverHelp' => {
        message     => q|Choose the main template for viewing the inbox|,
        lastUpdated => 1119068809
    },

    'inbox view message template label' => {
        message     => q|View Message Template|,
        lastUpdated => 1119068809
    },

    'inbox view message template hoverHelp' => {
        message     => q|Choose the template for viewing a message in the inbox|,
        lastUpdated => 1119068809
    },

    'inbox send message template label' => {
        message     => q|Send Message Template|,
        lastUpdated => 1119068809,
    },

    'inbox send message template hoverHelp' => {
        message     => q|Choose the template for sending a message|,
        lastUpdated => 1119068809,
    },

    'inbox message confirm template label' => {
        message     => q|Inbox Message Confirm Template|,
        lastUpdated => 1119068809
    },

    'inbox message confirm template hoverHelp' => {
        message     => q|Choose the template for displaying confirmation that a message has been sent|,
        lastUpdated => 1119068809
    },

    'inbox error message template label' => {
        message     => q|Inbox Error Message Template|,
        lastUpdated => 1119068809
    },

    'inbox error message template hoverHelp' => {
        message     => q|Choose the template for viewing inbox errors|,
        lastUpdated => 1119068809
    },

    'inbox manage invitations template label' => {
        message     => q|Manage Invitations Template|,
        lastUpdated => 1119068809
    },

    'inbox manage invitations template hoverHelp' => {
        message     => q|Choose the template to use for managing invitations|,
        lastUpdated => 1228773936
    },

    'invitation confirm message template label' => {
        message     => q|Invitation Confirmation Message Template|,
        lastUpdated => 1119068809
    },

    'invitation confirm message template hoverHelp' => {
        message     => q|Choose the template for viewing invitation confirmations|,
        lastUpdated => 1119068809
    },

    'inbox view invitation template label' => {
        message     => q|View Invitation Template|,
        lastUpdated => 1119068809
    },

    'inbox view invitation template hoverHelp' => {
        message     => q|Choose the template for viewing an invitation|,
        lastUpdated => 1119068809
    },

    'invite user enabled template label' => {
        message     => q|Enable user invitations?|,
        lastUpdated => 1119068809
    },

    'invite user enabled template hoverHelp' => {
        message     => q|Enable users to send emails to their friends, inviting them to come and create an account on this site.  Please note:  In order for this feature to work you must also enable anonymous registration|,
        lastUpdated => 1119068809
    },

    'invite user restrict subject template label' => {
        message     => q|Restrict Invitation Subject?|,
        lastUpdated => 1119068809
    },

    'invite user restrict subject template hoverHelp' => {
        message     => q|If this setting is 'yes', users will not be able to modify the default subject of the invitation|,
        lastUpdated => 1119068809
    },

    'invite user subject template label' => {
        message     => q|Default Invitation Subject|,
        lastUpdated => 1119068809
    },

    'invite user subject template hoverHelp' => {
        message     => q|Enter the default text for the subject of user invitations.  Macros will be processed on this field (macros will not be processed on the actual subject sent)|,
        lastUpdated => 1119068809
    },

    'invite user restrict message template label' => {
        message     => q|Restrict Invitation Message?|,
        lastUpdated => 1119068809
    },

    'invite user restrict message template hoverHelp' => {
        message     => q|If this setting is 'yes', users will not be able to modify the default message of the invitation|,
        lastUpdated => 1119068809
    },

    'invite user message label' => {
        message     => q|Default Invitation Message|,
        lastUpdated => 1119068809
    },

    'invite user message hoverHelp' => {
        message     => q|Enter the default text for the message of user invitations.  Macros will be processed on this field (macros will not be processed on the actual message sent)|,
        lastUpdated => 1119068809
    },

    'invite user message template label' => {
        message     => q|Invitation Email Template|,
        lastUpdated => 1119068809
    },

    'invite user message template hoverHelp' => {
        message     => q|Choose the template for the email that will be sent as the user invitation.  This will include the text of the message as well as the registration link and any headers or footers you choose to add to the message.|,
        lastUpdated => 1119068809
    },

    'invite user template label' => {
        message     => q|Invite User Send Template|,
        lastUpdated => 1227564609
    },

    'invite user template hoverHelp' => {
        message     => q|Choose the template for viewing the main user invitation screen|,
        lastUpdated => 1119068809
    },

    'invite user confirm template label' => {
        message     => q|Invite User Confirmation Template|,
        lastUpdated => 1119068809
    },

    'invite user confirm template hoverHelp' => {
        message     => q|Choose the template for viewing user invitation confirmations|,
        lastUpdated => 1119068809
    },


    'subject label' => {
        message     => q|Subject|,
        lastUpdated => 1119068809
    },

    'status label' => {
        message     => q{Status},
        lastUpdated => 1119068809
    },

    'date label' => {
        message     => q{Date},
        lastUpdated => 1119068809
    },

    'received label' => {
        message     => q{Received},
        lastUpdated => 1119068809
    },

    'recipients label' => {
        message     => q{Add Recipients},
        lastUpdated => 1119068809
    },

    'from label' => {
        message     => q{From},
        lastUpdated => 1119068809
    },

    'to label' => {
        message     => q{To},
        lastUpdated => 1119068809
    },

    'member since' => {
        message     => q{Member Since },
        lastUpdated => 1119068809
    },

    'delete label' => {
        message     => q{Delete},
        lastUpdated => 1119068809
    },

    'view my profile' => {
        message     => q{view my profile as others see it},
        lastUpdated => 1119068809
    },

    'messages label' => {
        message     => q{Messages},
        lastUpdated => 1119068809
    },

    'invitations label' => {
        message     => q{Invitations},
        lastUpdated => 1119068809
    },

    'previous label' => {
        message     => q{Previous},
        lastUpdated => 1119068809
    },

    'next label' => {
        message     => q{Next},
        lastUpdated => 1119068809
    },

    'reply label' => {
        message     => q{Reply},
        lastUpdated => 1119068809
    },

    'cancel label' => {
        message     => q{Cancel},
        lastUpdated => 1119068809
    },

    'back label' => {
        message     => q{Back to Inbox},
        lastUpdated => 1119068809
    },

    'new message label' => {
        message     => q{New Message},
        lastUpdated => 1119068809
    },

    'send label' => {
        message => q{Send},
        lastUpdated => 1181019679,
    },

    'no access' => {
        message     => q{You do not have permission to view this message.},
        lastUpdated => 1119068809
    },

    'no reply error' => {
        message     => q{You do not have permission to reply to this message.},
        lastUpdated => 1119068809
    },

    'system message error' => {
        message     => q{This message was sent by the system and cannot be replied to},
        lastUpdated => 1119068809
    },

    'message does not exist' => {
        message     => q{The message you are trying to view has been deleted.},
        lastUpdated => 1119068809
    },

    'message count' => {
        message     => q{messages},
        lastUpdated => 1119068809
    },

    'compose message label' => {
        message     => q{Compose new message},
        lastUpdated => 1119068809
    },

    'reply message label' => {
        message     => q{Reply to message},
        lastUpdated => 1119068809
    },

    'no self error' => {
        message => q|You may not send messages to yourself.|,
        lastUpdated => 1181019679,
    },

    'no friends error' => {
        message => q{You do not have any active friends in the system.  If you wish to send a new private message to a user without having to locate their profile, you must first add them as a friend.},
        lastUpdated => 1181019679,
    },

    'no messagable friends error' => {
        message => q{None of your friends allow private messaging.},
        lastUpdated => 1244494607,
    },

    'no friends hover' => {
        message => q{You must have active friends in the system if you wish to send new private messages without having to first locate their profile},
        lastUpdated => 1181019679,
    },

    'no subject error' => {
        message => q{You have not entered a subject for this message},
        lastUpdated => 1181019679,
    },

    'no message error' => {
        message => q{You have not entered a message},
        lastUpdated => 1181019679,
    },

    'no user error' => {
        message => q{You have not selected anyone to send this message to},
        lastUpdated => 1181019679,
    },

    'blocked error' => {
        message => q|This user does not wish to receive private messages.|,
        lastUpdated => 1181019679,
    },

    'remove text' => {
        message => q{remove},
        lastUpdated => 1181019679,
    },

    'update label' => {
        message => q{Update},
        lastUpdated => 1181019679,
    },

    'message sent label' => {
        message => q{Message Sent},
        lastUpdated => 1181019679,
    },

    'message sent text' => {
        message => q{Your message has been sent successfully},
        lastUpdated => 1181019679,
    },

    'error label' => {
        message     => q{Error},
        lastUpdated => 1225724810,
    },

    'invitation label' => {
        message     => q{Invitation},
        lastUpdated => 1225724810,
    },

    'invitation count' => {
        message     => q{invitations},
        lastUpdated => 1225724810,
    },

    'invitation message' => {
        message     => q{%s has invited you to join their friends newtork},
        lastUpdated => 1225724810,
    },

    'no invitations' => {
        message     => q{You have no outstanding friends invitations},
        lastUpdated => 1225724810,
    },

    'accept button label' => {
        message     => q{Accept},
        lastUpdated => 1225724810,
    },

    'deny button label' => {
        message     => q{Deny},
        lastUpdated => 1225724810,
    },

    'invitation confirm label' => {
        message     => q{Invitation Notices Sent},
        lastUpdated => 1225724810,
    },

    'invitation confirm message' => {
        message     => q{The following actions were taken:},
        lastUpdated => 1225724810,
    },

    'invitations back label' => {
        message     => q{back to invitations},
        lastUpdated => 1225724810,
    },

    'invitation does not exist' => {
        message     => q{The invitation you are trying to view has already been approved or denied.},
        lastUpdated => 1119068809
    },

    'no access to invitation' => {
        message     => q{You do not have permission to view this invitation.},
        lastUpdated => 1119068809
    },

    'inviter no longer exists' => {
        message     => q{The user who sent this invitation is no longer a member of the site.},
        lastUpdated => 1119068809
    },

    'invite a friend' => {
        message     => q{invite a friend to join this website},
        lastUpdated => 1119068809
    },

    'invite subject' => {
        message     => q{An invitation to join %s},
        lastUpdated => 1119068809
    },

    'invite message' => {
        message     => q{I'm a member of a site that I thought you would find very useful, so I'm sending this invitation hoping you'll join me here. Click on the link below to register.},
        lastUpdated => 1119068809,
    },

    'missing email' => {
        message => q|The invitation cannot be sent because you did not enter an email address.|,
        lastUpdated => 1181409056,
    },

    'invalid email' => {
		message => q|Invalid email address entered: %s.|,
		lastUpdated => 1181409056,
	},

	'missing message' => {
		message     => q|Your invitiation must have a message.|,
		lastUpdated => 1181409432,
	},

    'missing subject' => {
        message     => q|Your invitation must have a subject.|,
        lastUpdated => 1181409433,
    },

    'already a member' => {
        message     => q|The email address you entered is already registered to <a href="%s">%s</a> on this site.|,
        lastUpdated => 1227715272,
    },

    'currently invited' => {
		message     => q|The email address you entered, %s, has an outstanding invitation on this site.|,
		lastUpdated => 1227715272,
	},

    'no email' => {
        message     => q{The invitation cannot be sent because you do not have an email address set in your profile.},
        lastUpdated => 1119068809,
    },

    'invitation sent label' => {
        message => q|Invitation Sent|,
        lastUpdated => 1181410226,
    },

    'invitation sent text' => {
        message => q|Your invitation has been sent successfully.|,
        lastUpdated => 1181410226,
    },

    'common account variables' => {
        message => q|Common Account, Inbox Plugin, Template Variables.|,
        lastUpdated => 1230867391,
    },

    'view_inbox_url' => {
        message => q|URL to view the Inbox screen.|,
        lastUpdated => 1230867391,
    },

    'view_invitations_url' => {
        message => q|URL to view the Invitations screen.|,
        lastUpdated => 1230867391,
    },

    'unread_message_count' => {
        message => q|The number of unread messages in the Inbox.|,
        lastUpdated => 1230867391,
    },

    'invitation_count' => {
        message => q|The number of Invitations this user has received.|,
        lastUpdated => 1230867391,
    },

    'invitations_enabled' => {
        message => q|A boolean that is true if the user is willing to receive invitations to join Friends Networks on this site.|,
        lastUpdated => 1230867391,
    },

    'user_invitations_enabled' => {
        message => q|A boolean that is true if this site is configured to send invitations to users outside of the site.|,
        lastUpdated => 1230867391,
    },

    'invite_friend_url' => {
        message => q|The URL to invite this user to be join your Friend Network.|,
        lastUpdated => 1230867391,
    },

    'inbox rich editor label' => {
        message         => q{Inbox Rich Editor},
        lastUpdated     => 0,
        context         => q{Label for setting},
    },

    'inbox rich editor description' => {
        message         => q{The rich editor used to compose messages},
        lastUpdated     => 0,
        context         => "Description of Inbox setting",
    },

     'subject_url' => {
         message         => q{The URL to sort the inbox by subject.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'status_url' => {
         message         => q{The URL to sort the inbox by status.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'from_url' => {
         message         => q{The URL to sort the inbox by who sent the messages.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'dateStamp_url' => {
         message         => q{The URL to sort the inbox by when the message was sent.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'rpp_url' => {
         message         => q{The current URL with sort, sort direction and user filtering params added.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'has_messages' => {
         message         => q{A boolean which is true if the user has messages.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'message_total' => {
         message         => q{The total number of messages the user has in their inbox.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'new_message_url' => {
         message         => q{The URL to take the user to the screen where they can send new messages to other users.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'canSendMessages' => {
         message         => q{A boolean which is true if the user has friends that he can send messages to.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'message_loop' => {
         message         => q{A loop containing all messages, as determined by the sorting and number of messages per page options.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'view inbox template' => {
         message         => q{View Inbox Template},
         lastUpdated     => 1235421123,
         context         => "The template that allows you to view the contents of the Inbox",
     },

     'message_rpp' => {
         message         => q{A select box that allows the user to change the number of messages displayed per page},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'form_header' => {
         message         => q{HTML elements to begin the form on this page},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'form_footer' => {
         message         => q{HTML elements to end the form on this page},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'message_id' => {
         message         => q{The unique identifier for this message.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'message_url' => {
         message         => q{The URL to view the contents of this message.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'subject' => {
         message         => q{The subject of this message.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'status' => {
         message         => q{The status of this message, internationalized.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'status_class' => {
         message         => q{The status of this message, raw.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'isRead' => {
         message         => q{A boolean which will be true if this message has been read.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'isReplied' => {
         message         => q{A boolean which will be true if this message has been replied to.},
         lastUpdated     => 1235421123,
         context         => "template variable for view inbox template",
     },

     'isPending' => {
         message      => q{A boolean which will be true if this message represents an action by the user that is pending.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'isCompleted' => {
         message      => q{A boolean which will be true if this message represents an action by the user that has been completed.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'from_id' => {
         message      => q{The userId of the person who sent this message.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'from_url' => {
         message      => q{The URL to view the profile of the user who sent this message.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'from' => {
         message      => q{The name of the person who sent this message.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'dateStamp' => {
         message      => q{The date the message was sent, as an epoch.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'dateStamp_formatted' => {
         message      => q{The date the message was sent, using the user's preferred date and time format.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'inbox_form_delete' => {
         message      => q{A little checkbox for the user to check if they want to delete this message.},
         lastUpdated  => 1235421123,
         context      => "template variable for view inbox template",
     },

     'userFilter' => {
         message         => q{A select box form element to filter the list of messages by who sent them.},
         lastUpdated     => 1235421123,
         context         => "Description of Inbox setting",
     },

     'All users' => {
         message         => q{All users},
         lastUpdated     => 1235421123,
         context         => "Default setting for filtering in the Inbox.  Short for Show messages from all users.",
     },

    'inbox copy sender label' => {
        message     => q|Copy Sender on Messages?|,
        context     => q|Copy, as in receive a copy.  Label for Account/Inbox settings|,
        lastUpdated => 0,
    },

    'inbox copy sender hoverHelp' => {
        message     => q|If this setting is 'yes', users will receive a copy of messages that they send using the inbox.|,
        lastUpdated => 0,
    },
 
    'send inbox notifications only' => {
        message => q|Send only Inbox notifications|,
        context => q|Site setting.  A notification is a short message that a message is in the Inbox.|,
        lastUpdated => 1235685248,
    },

    'send inbox notifications only help' => {
        message => q|Should WebGUI just send notifications about Inbox messages, instead of the message itself?|,
        lastUpdated => 1235696295,
    },
    
    'inbox notifications subject' => {
        message => q|Inbox Notification Email Subject|,
        context => q|Site setting.  A notification is a short message that a message is in the Inbox.|,
        lastUpdated => 0,
    },

    'inbox notifications subject help' => {
        message => q|The email subject to use for inbox notifications|,
        lastUpdated => 0,
    },

    'inbox notification' => {
        message => q|You have a new message in your Inbox.|,
        lastUpdated => 1235708853,
    },
 
    'inbox notification template' => {
        message => q|Inbox Notification Template|,
        context => q|Site setting.  A notification is a short message that a message is in the Inbox.|,
        lastUpdated => 1242274705,
    },

    'inbox notification template help' => {
        message => q|Choose a template that will be used to display Inbox Notifications.|,
        lastUpdated => 1242274703,
    },
    
    'inbox sms notification' => {
        message => q|You have a new message in your Inbox.|,
        lastUpdated => 1235708853,
    },
 
    'inbox sms notification template' => {
        message => q|Inbox SMS Notification Template|,
        context => q|Site setting.  A notification is a short SMS message that a message is in the Inbox.|,
        lastUpdated => 1242274705,
    },

    'inbox sms notification template help' => {
        message => q|Choose a template that will be used to display Inbox SMS Notifications.|,
        lastUpdated => 1242274703,
    },


    'send reject notice' => {
        message => q|Send Reject Friend Notifications|,
        context => q|Site setting.  A notification is an email that is sent to the user being rejected.|,
        lastUpdated => 1242274705,
    },

    'send reject notice help' => {
        message => q|Choose whether or not, upon rejecting a friend request, a notification should be sent to the user being rejected.|,
        lastUpdated => 1242274703,
    },

};

1;
